==> apache-geode-1.13.8-src.tgz: apache-geode-1.13.8-src/geode-junit/src/integrationTest/java/org/apache/geode/test/junit/internal/JUnitSanctionedSerializablesServiceIntegrationTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.test.junit.internal;

import org.junit.experimental.categories.Category;

import org.apache.geode.codeAnalysis.SanctionedSerializablesServiceIntegrationTestBase;
import org.apache.geode.internal.CoreSanctionedSerializablesService;
import org.apache.geode.internal.serialization.SanctionedSerializablesService;
import org.apache.geode.test.junit.categories.SanctionedSerializablesTest;
import org.apache.geode.test.junit.categories.SerializationTest;

@Category({SerializationTest.class, SanctionedSerializablesTest.class})
public class JUnitSanctionedSerializablesServiceIntegrationTest
    extends SanctionedSerializablesServiceIntegrationTestBase {

  private final SanctionedSerializablesService service = new CoreSanctionedSerializablesService();

  @Override
  protected SanctionedSerializablesService getService() {
    return service;
  }

  @Override
  protected ServiceResourceExpectation getServiceResourceExpectation() {
    return ServiceResourceExpectation.NON_EMPTY;
  }
}

==> apache-geode-1.15.2-src.tgz: apache-geode-1.15.2-src/geode-junit/src/integrationTest/java/org/apache/geode/test/junit/internal/JUnitSanctionedSerializablesServiceIntegrationTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
package org.apache.geode.test.junit.internal;

import org.junit.experimental.categories.Category;

import org.apache.geode.codeAnalysis.SanctionedSerializablesServiceIntegrationTestBase;
import org.apache.geode.internal.serialization.filter.SanctionedSerializablesService;
import org.apache.geode.test.junit.categories.SanctionedSerializablesTest;
import org.apache.geode.test.junit.categories.SerializationTest;

@Category({SerializationTest.class, SanctionedSerializablesTest.class})
public class JUnitSanctionedSerializablesServiceIntegrationTest
    extends SanctionedSerializablesServiceIntegrationTestBase {

  private final SanctionedSerializablesService service = new JUnitSanctionedSerializablesService();

  @Override
  protected SanctionedSerializablesService getService() {
    return service;
  }

  @Override
  protected ServiceResourceExpectation getServiceResourceExpectation() {
    return ServiceResourceExpectation.NON_EMPTY;
  }
}
